monnier pushed a commit to branch master
in repository elpa.

commit f52e8804ef0b3edfced6828c8b5a69ac1fc6f68f
Author: Teemu Likonen <tliko...@iki.fi>
Date:   Wed Dec 29 11:11:35 2010 +0000

    Dokumentteja ajan tasalle: tarkistusohjelma voi olla myös funktio
---
 wcheck-mode.el |   18 +++++++++---------
 1 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/wcheck-mode.el b/wcheck-mode.el
index 6d1dbb9..fccfa6b 100644
--- a/wcheck-mode.el
+++ b/wcheck-mode.el
@@ -703,8 +703,7 @@ right-click mouse menu)."
     ;; Turn off the mode.
 
     ;; We clear overlays form the buffer, remove the buffer from buffer
-    ;; database and clear the variable holding strings received from
-    ;; external process.
+    ;; database.
     (wcheck-remove-overlays)
     (wcheck-update-buffer-data (current-buffer) nil)
 
@@ -750,13 +749,14 @@ right-click mouse menu)."
 
 
 (defun wcheck-timer-read-event ()
-  "Send windows' content to external program.
-This function is usually called by the wcheck-mode idle timer.
-The function walks through all windows which belong to the buffer
+  "Send windows' content to checker program or function.
+
+This function is usually called by the `wcheck-mode' idle timer.
+The function walks through all windows which belong to buffers
 that have requested update. It reads windows' content and sends
-it to the external program associated with the buffer. Finally,
-this function starts another idle timer for marking strings in
-buffers."
+it checker program or function associated with the buffer's
+language. Finally, this function starts another idle timer for
+marking strings in buffers."
 
   (dolist (buffer wcheck-timer-read-requested)
     (when (buffer-live-p buffer)
@@ -789,7 +789,7 @@ buffers."
             (setq strings (append (wcheck-read-strings
                                    buffer (car area) (cdr area))
                                   strings)))
           ;; Send strings to external process.
           (wcheck-send-strings buffer strings)))))
 
   ;; Start a timer which will mark text in buffers/windows.
@@ -789,7 +789,7 @@ buffers."
                                    buffer (car area) (cdr area))
                                   strings)))
-          ;; Send strings to external process.
+          ;; Send strings to checker engine.
           (wcheck-send-strings buffer strings)))))
 

Reply via email to